import * as cdk from 'aws-cdk-lib';
import * as constructs from 'constructs';
/**
 * Creates a serverless vector database with SvectorDB, sign up at https://svectordb.com to get started
 *
 * @schema CfnDatabaseProps
 */
export interface CfnDatabaseProps {
    /**
     * (Advanced use cases only) - Custom endpoint URL for contacting the SvectorDB API
     *
     * @schema CfnDatabaseProps#EndpointUrl
     */
    readonly endpointUrl?: string;
    /**
     * Integration ID
     *
     * @schema CfnDatabaseProps#IntegrationId
     */
    readonly integrationId: string;
    /**
     * Name that appears in the SvectorDB console
     *
     * @schema CfnDatabaseProps#Name
     */
    readonly name?: string;
    /**
     * @schema CfnDatabaseProps#Type
     */
    readonly type?: CfnDatabasePropsType;
    /**
     * @schema CfnDatabaseProps#Metric
     */
    readonly metric: CfnDatabasePropsMetric;
    /**
     * @schema CfnDatabaseProps#Dimension
     */
    readonly dimension: number;
}
/**
 * Converts an object of type 'CfnDatabaseProps' to JSON representation.
 */
export declare function toJson_CfnDatabaseProps(obj: CfnDatabaseProps | undefined): Record<string, any> | undefined;
/**
 * @schema CfnDatabasePropsType
 */
export declare enum CfnDatabasePropsType {
    /** SANDBOX */
    SANDBOX = "SANDBOX",
    /** STANDARD */
    STANDARD = "STANDARD"
}
/**
 * @schema CfnDatabasePropsMetric
 */
export declare enum CfnDatabasePropsMetric {
    /** EUCLIDEAN */
    EUCLIDEAN = "EUCLIDEAN",
    /** DOT_PRODUCT */
    DOT_UNDERSCORE_PRODUCT = "DOT_PRODUCT",
    /** COSINE */
    COSINE = "COSINE"
}
/**
 * A CloudFormation `SvectorDB::VectorDatabase::Database`
 *
 * @cloudformationResource SvectorDB::VectorDatabase::Database
 * @stability external
 * @link http://unknown-url
 */
export declare class CfnDatabase extends cdk.CfnResource {
    /**
    * The CloudFormation resource type name for this resource class.
    */
    static readonly CFN_RESOURCE_TYPE_NAME = "SvectorDB::VectorDatabase::Database";
    /**
     * Resource props.
     */
    readonly props: CfnDatabaseProps;
    /**
     * Attribute `SvectorDB::VectorDatabase::Database.Id`
     * @link http://unknown-url
     */
    readonly attrId: string;
    /**
     * Create a new `SvectorDB::VectorDatabase::Database`.
     *
     * @param scope - scope in which this resource is defined
     * @param id    - scoped id of the resource
     * @param props - resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnDatabaseProps);
}
